==> pmml-springboot-example-1.8.0.Final-sources.jar: testminingmodel/predicatesmining/predicatesminingsegmentation/predicatesminingsegment0/segmentpredicatesminingsegment0regressionmodel/SegmentPredicatesMiningSegment0RegressionModel.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package testminingmodel.predicatesmining.predicatesminingsegmentation.predicatesminingsegment0.segmentpredicatesminingsegment0regressionmodel;

import java.util.Collections;
import java.util.Map;
import org.kie.pmml.commons.model.KiePMMLOutputField;
import org.kie.pmml.models.regression.model.KiePMMLRegressionModel;

public class SegmentPredicatesMiningSegment0RegressionModel extends KiePMMLRegressionModel {

    public SegmentPredicatesMiningSegment0RegressionModel() {
        super("SegmentPredicatesMiningSegment0RegressionModel");
        regressionTable = new testminingmodel.predicatesmining.predicatesminingsegmentation.predicatesminingsegment0.segmentpredicatesminingsegment0regressionmodel.KiePMMLRegressionTableRegression5();
        targetField = "categoricalResult";
        miningFunction = org.kie.pmml.api.enums.MINING_FUNCTION.REGRESSION;
        pmmlMODEL = org.kie.pmml.api.enums.PMML_MODEL.REGRESSION_MODEL;
        miningFields.add(new org.kie.pmml.api.models.MiningField("categoricalResult", org.kie.pmml.api.enums.FIELD_USAGE_TYPE.PREDICTED, null, org.kie.pmml.api.enums.DATA_TYPE.DOUBLE, null, java.util.Arrays.asList(), java.util.Arrays.asList()));
        miningFields.add(new org.kie.pmml.api.models.MiningField("categoricalX", org.kie.pmml.api.enums.FIELD_USAGE_TYPE.ACTIVE, null, org.kie.pmml.api.enums.DATA_TYPE.STRING, null, java.util.Arrays.asList("red", "green", "blue", "orange", "yellow"), java.util.Arrays.asList()));
        miningFields.add(new org.kie.pmml.api.models.MiningField("categoricalY", org.kie.pmml.api.enums.FIELD_USAGE_TYPE.ACTIVE, null, org.kie.pmml.api.enums.DATA_TYPE.STRING, null, java.util.Arrays.asList("classA", "classB", "classC"), java.util.Arrays.asList()));
        outputFields.add(new org.kie.pmml.api.models.OutputField("Predicted_result", org.kie.pmml.api.enums.OP_TYPE.CONTINUOUS, org.kie.pmml.api.enums.DATA_TYPE.DOUBLE, null, org.kie.pmml.api.enums.RESULT_FEATURE.PREDICTED_VALUE, null));
        kiePMMLOutputFields.add(KiePMMLOutputField.builder("Predicted_result", Collections.emptyList()).withRank(1).withResultFeature(org.kie.pmml.api.enums.RESULT_FEATURE.PREDICTED_VALUE).build());
    }
}

==> pmml-springboot-example-1.9.0.Final-sources.jar: testminingmodel/predicatesmining/predicatesminingsegmentation/predicatesminingsegment0/segmentpredicatesminingsegment0regressionmodel/SegmentPredicatesMiningSegment0RegressionModel.java <==
package testminingmodel.predicatesmining.predicatesminingsegmentation.predicatesminingsegment0.segmentpredicatesminingsegment0regressionmodel;

import java.util.Arrays;
import java.util.Collections;
import org.kie.pmml.commons.model.KiePMMLOutputField;
import org.kie.pmml.commons.model.expressions.*;
import org.kie.pmml.commons.transformations.*;
import org.kie.pmml.models.regression.model.KiePMMLRegressionModel;

public class SegmentPredicatesMiningSegment0RegressionModel extends KiePMMLRegressionModel {

    public SegmentPredicatesMiningSegment0RegressionModel() {
        super("SegmentPredicatesMiningSegment0RegressionModel");
        regressionTable = new testminingmodel.predicatesmining.predicatesminingsegmentation.predicatesminingsegment0.segmentpredicatesminingsegment0regressionmodel.KiePMMLRegressionTableRegression5();
        targetField = "categoricalResult";
        miningFunction = org.kie.pmml.api.enums.MINING_FUNCTION.REGRESSION;
        pmmlMODEL = org.kie.pmml.api.enums.PMML_MODEL.REGRESSION_MODEL;
        transformationDictionary = null;
        localTransformations = null;
        miningFields.add(new org.kie.pmml.api.models.MiningField("categoricalResult", org.kie.pmml.api.enums.FIELD_USAGE_TYPE.PREDICTED, null, org.kie.pmml.api.enums.DATA_TYPE.DOUBLE, null, java.util.Arrays.asList(), java.util.Arrays.asList()));
        miningFields.add(new org.kie.pmml.api.models.MiningField("categoricalX", org.kie.pmml.api.enums.FIELD_USAGE_TYPE.ACTIVE, null, org.kie.pmml.api.enums.DATA_TYPE.STRING, null, java.util.Arrays.asList("red", "green", "blue", "orange", "yellow"), java.util.Arrays.asList()));
        miningFields.add(new org.kie.pmml.api.models.MiningField("categoricalY", org.kie.pmml.api.enums.FIELD_USAGE_TYPE.ACTIVE, null, org.kie.pmml.api.enums.DATA_TYPE.STRING, null, java.util.Arrays.asList("classA", "classB", "classC"), java.util.Arrays.asList()));
        outputFields.add(new org.kie.pmml.api.models.OutputField("Predicted_result", org.kie.pmml.api.enums.OP_TYPE.CONTINUOUS, org.kie.pmml.api.enums.DATA_TYPE.DOUBLE, null, org.kie.pmml.api.enums.RESULT_FEATURE.PREDICTED_VALUE, null));
        kiePMMLOutputFields.add(KiePMMLOutputField.builder("Predicted_result", Collections.emptyList()).withRank(1).withResultFeature(org.kie.pmml.api.enums.RESULT_FEATURE.PREDICTED_VALUE).build());
    }
}
